@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.38'; # VERSION
+our $VERSION = '0.39'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -21,7 +21,7 @@ use Dist::Zilla::PluginBundle::Git 2.028;
 use Dist::Zilla::Plugin::Git::NextVersion;
 use Dist::Zilla::Plugin::AutoMetaResourcesPrefixed;
 
-use Dist::Zilla::Plugin::ContributorsFromGit;
+use Dist::Zilla::Plugin::Git::Contributors;
 
 use Dist::Zilla::Plugin::PruneCruft;
 use Dist::Zilla::Plugin::ManifestSkip;
@@ -31,6 +31,7 @@ use Dist::Zilla::Plugin::InsertCopyright;
 
 use Dist::Zilla::Plugin::TaskWeaver;
 use Dist::Zilla::Plugin::PodWeaver;
+use Pod::Weaver::Section::Badges;
 
 use Dist::Zilla::Plugin::ReadmeAnyFromPod;
 
@@ -63,7 +64,7 @@ use Dist::Zilla::Plugin::MakeMaker::Awesome;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::CheckMetaResources;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
-use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.0.15;
+use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.109;
 use Dist::Zilla::Plugin::ChangelogFromGit::Debian;
 use Dist::Zilla::Plugin::Control::Debian;
 use Dist::Zilla::Plugin::CheckChangesHasContent;
@@ -295,14 +296,16 @@ sub configure {
         (
             $self->no_git
             ? ()
-            : 'ContributorsFromGit'
+            : 'Git::Contributors'
         ),
 
         [
-            'PruneCruft' => { except => '\.travis.yml', }    # core
+            'PruneCruft' => {
+                except => '\.travis.yml',
+              }    # core
         ],
 
-        'ManifestSkip',                                      # core
+        'ManifestSkip',    # core
 
         # file munging
         'OurPkgVersion',
@@ -380,7 +383,11 @@ sub configure {
             $self->no_critic ? ()
             : ('Test::Perl::Critic')
         ),
-        [ 'Test::Kwalitee::Extra' => { has_corpus => 0, }, ],
+        [
+            'Test::Kwalitee::Extra' => {
+                has_corpus => 0,
+            },
+        ],
         'MetaTests',         # core
         'PodSyntaxTests',    # core
         (
@@ -498,8 +505,9 @@ sub configure {
             ? ()
             : (
                 [
-                    'Git::Commit' => 'Commit_Dirty_Files' =>
-                      { allow_dirty => [qw/dist.ini README.md .travis.yml/] }
+                    'Git::Commit' => 'Commit_Dirty_Files' => {
+                        allow_dirty => [qw/dist.ini README.md .travis.yml/]
+                    }
                 ],
                 [ 'Git::Tag' => { tag_format => $self->tag_format } ],
             )
@@ -507,8 +515,9 @@ sub configure {
 
         # bumps Changes
         [
-            'NextRelease' =>
-              { format => '%n%v%n%n%t- %{yyyy-MM-dd HH:mm:ss VVVV}d%n', },
+            'NextRelease' => {
+                format => '%n%v%n%n%t- %{yyyy-MM-dd HH:mm:ss VVVV}d%n',
+            },
         ],    # core (also munges files)
 
         (
@@ -534,7 +543,7 @@ __PACKAGE__->meta->make_immutable;
 #
 # This file is part of Dist-Zilla-PluginBundle-SHANTANU
 #
-# This software is copyright (c) 2015 by Shantanu Bhadoria.
+# This software is copyright (c) 2016 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -548,9 +557,23 @@ __END__
 
 Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to use it
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/shantanubhadoria/perl-Dist-Zilla-PluginBundle-SHANTANU"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Dist-Zilla-PluginBundle-SHANTANU.svg?branch=build/master" alt="Travis status" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-PluginBundle-SHANTANU%200.39"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-PluginBundle-SHANTANU/0.39" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Dist-Zilla-PluginBundle-SHANTANU-0.39"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Zilla-PluginBundle-SHANTANU/0.39" alt="Distribution kwalitee" /></a>
+<a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
+</p>
+
+=end html
+
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -559,18 +582,18 @@ version 0.38
 
 =head1 DESCRIPTION
 
-This is a L<Dist::Zilla> PluginBundle. The way I use it. While this bundle is 
-customized to my needs, others might be better of forking this repository and 
-modifying it to their own needs or using the more mature Plugin bundles that 
-this is derived from like the one by David Golden. 
+This is a L<Dist::Zilla> PluginBundle. The way I use it. While this bundle is
+customized to my needs, others might be better of forking this repository and
+modifying it to their own needs or using the more mature Plugin bundles that
+this is derived from like the one by David Golden.
 
 =head1 ATTRIBUTES
 
-=head2 makemaker 
+=head2 makemaker
 
 makemaker attribute By default uses [MakeMaker::Awesome] This can be overriden by defining this attribute
 
-=head2 skip_makemaker 
+=head2 skip_makemaker
 
 Skip Default Makemaker option to add your own plugin for generating makefile
 
@@ -582,7 +605,7 @@ no_git attribute
 
 no_commitbuild attribute, do not create a build branch
 
-=head2 version_regexp 
+=head2 version_regexp
 
 version_regexp attribute
 
@@ -765,15 +788,25 @@ L<https://github.com/shantanubhadoria/perl-dist-zilla-pluginbundle-shantanu>
 
 Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Shantanu Bhadoria
+=for stopwords Karen Etheridge Shantanu Bhadoria
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
 
 Shantanu Bhadoria <shantanu att cpan dott org>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Shantanu Bhadoria.
+This software is copyright (c) 2016 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
