@@ -3,7 +3,7 @@ use warnings;
 
 package Pod::Weaver::PluginBundle::SHANTANU;
 
-our $VERSION = '0.38'; # VERSION
+our $VERSION = '0.39'; # VERSION
 
 use Pod::Weaver 3.101638;
 use Pod::Weaver::Config::Assembler;
@@ -11,8 +11,11 @@ use Pod::Weaver::Config::Assembler;
 # Dependencies
 use Pod::Weaver::Plugin::WikiDoc ();
 use Pod::Elemental::Transformer::List 0.101620 ();
-use Pod::Weaver::Section::Support 1.001        ();
-use Pod::Weaver::Section::Contributors 0.001   ();
+use Pod::Weaver::Section::Badges 0.0402        ();
+use Badge::Depot::Plugin::Travis;
+use Badge::Depot::Plugin::Gratipay;
+use Pod::Weaver::Section::Support 1.001      ();
+use Pod::Weaver::Section::Contributors 0.001 ();
 
 sub _exp { Pod::Weaver::Config::Assembler->expand_package( $_[0] ) }
 
@@ -35,7 +38,6 @@ sub mvp_bundle_config {
         [ '@SHANTANU/CorePrep', _exp('@CorePrep'), {} ],
         [ '@SHANTANU/Name',     _exp('Name'),      {} ],
         [ '@SHANTANU/Version',  _exp('Version'),   {} ],
-
         [ '@SHANTANU/Prelude', _exp('Region'), { region_name => 'prelude' } ],
         [ '@SHANTANU/Synopsis', _exp('Generic'), { header => 'SYNOPSIS' } ],
         [
@@ -64,6 +66,22 @@ sub mvp_bundle_config {
       (
         [ '@SHANTANU/Leftovers', _exp('Leftovers'), {} ],
         [ '@SHANTANU/postlude', _exp('Region'), { region_name => 'postlude' } ],
+        [
+            '@SHANTANU/Badges',
+            _exp('Badges'),
+            {
+                formats => 'html',
+                badge   => [
+                    'Perl',        'Shantanutravis',
+                    'Cpantesters', 'Kwalitee',
+                    'Gratipay'
+                ],
+                -perl_version        => '5.10+',
+                -shantanutravis_user => 'shantanubhadoria',
+                -travis_branch       => 'build/master',
+                -gratipay_user       => 'shantanubhadoria',
+            }
+        ],
         [
             '@SHANTANU/Support',
             _exp('Support'),
@@ -95,7 +113,7 @@ Pod::Weaver::PluginBundle::SHANTANU
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 METHODS
 
@@ -107,7 +125,7 @@ Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Shantanu Bhadoria.
+This software is copyright (c) 2016 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
